@@ -4,6 +4,7 @@ from .smms_img import SmmsImg
 from .user_exception import UserException
 from .download_help import DownloadHelp
 from .time_helper import TimeHelper
+import re
 
 
 class Main():
@@ -43,14 +44,32 @@ class Main():
         return SysConfig.getMarkdownImgDirPath()+'\\'+copyFileName
 
     def isImgFileName(self, file):
-        imgExts = ('.png','.gif','.jpg','.jpeg','.svg','.bmp')
+        imgExts = ('.png', '.gif', '.jpg', '.jpeg', '.svg', '.bmp')
         for imgExt in imgExts:
             if file.endswith(imgExt):
                 return True
         return False
 
+    def findHtmlImg(self, line, onlyLocal) -> list:
+        '''从字符串中查找html标签中的本地图片'''
+        findImgs = []
+        pattern = re.compile(r"<img src=\"(.+?)\"(.*)/>")
+        for matched in pattern.finditer(line):
+            imgFile = matched.group(1)
+            if self.isImgFileName(imgFile):
+                if not onlyLocal:
+                    findImgs.append(imgFile)
+                elif os.path.exists(imgFile):
+                    findImgs.append(imgFile)
+                else:
+                    pass
+        return findImgs
+
     def findLocalImageFile(self, line: str, localImages: set):
         '''递归查找某段字符串中中括号包裹的内容是否为本地图片'''
+        htmlImgs = self.findHtmlImg(line, True)
+        if htmlImgs:
+            localImages.update(htmlImgs)
         linePart = line.partition('(')
         if len(linePart[2]) > 0:
             secondPart = linePart[2].partition(')')
@@ -62,6 +81,9 @@ class Main():
 
     def findImagesInStr(self, line: str, localImages: list):
         '''递归查找某段字符串中中括号包裹的内容是否为本地图片'''
+        htmlImgs = self.findHtmlImg(line, False)
+        if htmlImgs:
+            localImages.update(htmlImgs)
         linePart = line.partition('(')
         if len(linePart[2]) > 0:
             secondPart = linePart[2].partition(')')
@@ -201,7 +223,7 @@ class Main():
             return False
 
     def changeImgService(self, selectedService):
-        supportedService = {'smms', 'ali', 'rruu', 'vimcn', 'yujian'}
+        supportedService = {'smms', 'ali', 'rruu', 'vimcn', 'yujian', 'ali2'}
         if selectedService not in supportedService:
             print('不支持的图床服务', selectedService)
             return False
@@ -212,6 +234,9 @@ class Main():
         elif selectedService == 'ali':
             sysConfig.setConfigParam(
                 Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_ALI)
+        elif selectedService == 'ali2':
+            sysConfig.setConfigParam(
+                Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_ALI2)
         elif selectedService == 'vimcn':
             sysConfig.setConfigParam(
                 Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_VIMCN)
